<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://www.feataholic.com
 * @since      @pkg.version@ @pkg.type@
 *
 * @package    MZLDR
 * @subpackage MZLDR/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    MZLDR
 * @subpackage MZLDR/public
 * @author     Your Name <email@example.com>
 */
class MZLDR_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @var  string  $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @var  string  $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * The Loader Model
	 *
	 * @var class $loader_model
	 */
	private $loader_model;

	/**
	 * The Impression Model
	 *
	 * @var class $impression_model
	 */
	private $impression_model;

	/**
	 * Initialize the class and set its properties.
	 */
	public function __construct( $plugin_name, $version ) {
		 $this->plugin_name = $plugin_name;
		$this->version      = $version;
		$this->loader_model = new MZLDR_Loader_Model();
		$this->impression_model = new MZLDR_Impression_Model();
	}
	
	/**
	 * Renders the loader
	 *
	 * @return  string
	 */
	public function render() {

		$mzldr_options = get_option( 'mzldr_settings_options' );

		// Check if we have the loader_display enabled first
		$mzldr_settings_field_loader_display = isset($mzldr_options['mzldr_settings_field_loader_display']) ? $mzldr_options['mzldr_settings_field_loader_display'] : '';
		$mzldr_settings_field_loader_display = ($mzldr_settings_field_loader_display == 'enable') ? true : false;
		if (!$mzldr_settings_field_loader_display) {
			return false;
		}
		
		$loader = $this->loader_model->getLatestLoader();

		// track impression
		if (count($loader)) {
			$this->impression_model->checkBeforeTrack($loader);
		}

		$loaders = $loader;
		if ($this->passPublishingRules($loader)) {
			require MZLDR_PUBLIC_PATH . 'partials/loader/tmpl.php';
		}
	}

	/**
	 * If we pass the publishing rules
	 * 
	 * @param   object   $loader
	 * 
	 * @return  boolean
	 */
	public function passPublishingRules($loader) {
		if (empty($loader)) {
			return array();
		}

		$parsed_data = $this->loader_model->parseLoaderData($loader[0]);

		$pass = false;

		$show_on_homepage = isset($parsed_data->settings->show_on_homepage) ? $parsed_data->settings->show_on_homepage : 'off';
		
		if ($show_on_homepage == 'on') {
			if ( is_front_page() && is_home() ) {
				$pass = true;
			} elseif ( is_front_page()){
				$pass = true;
			} elseif ( is_home()){
				$pass = true;
			}
		} else {
			$pass = true;
		}

		return $pass;
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @return  void
	 */
	public function enqueue_styles() {
		// Load Google Font
		wp_enqueue_style( $this->plugin_name . '-mazloader-google-font', 'https://fonts.googleapis.com/css?family=Poppins:400,700&display=swap', false );

		// Load MAZ Loader CSS
		wp_enqueue_style( $this->plugin_name, MZLDR_PUBLIC_MEDIA_URL . 'css/mazloader.css', array(), $this->version, 'all' );
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @return  void
	 */
	public function enqueue_scripts() {
		 // Load MAZ Loader JS
		wp_enqueue_script( $this->plugin_name, MZLDR_PUBLIC_MEDIA_URL . 'js/mazloader.js', array( 'jquery' ), $this->version, false );
	}

}
